# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator 1.0.1.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SourceConfiguration(Model):
    """SourceConfiguration.

    :param source_repository:
    :type source_repository: :class:`SourceRepository
     <azuretfs.models.SourceRepository>`
    :param source_version:
    :type source_version: str
    """

    _attribute_map = {
        'source_repository': {'key': 'sourceRepository', 'type': 'SourceRepository'},
        'source_version': {'key': 'sourceVersion', 'type': 'str'},
    }

    def __init__(self, source_repository=None, source_version=None):
        self.source_repository = source_repository
        self.source_version = source_version
