# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator 1.0.1.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RepositoryInfo(Model):
    """RepositoryInfo.

    :param id:
    :type id: str
    :param name:
    :type name: str
    :param url:
    :type url: str
    :param remote_url:
    :type remote_url: str
    :param project_info:
    :type project_info: TeamProjectInfo
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'url': {'key': 'url', 'type': 'str'},
        'remote_url': {'key': 'remoteUrl', 'type': 'str'},
        'project_info': {'key': 'project', 'type': 'TeamProjectInfo'},
    }

    def __init__(self, id=None, name=None, url=None, remote_url=None, project_info=None):
        self.id = id
        self.name = name
        self.url = url
        self.remote_url = remote_url
        self.project_info = project_info
