# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator 1.0.1.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ContinuousDeploymentConfiguration(Model):
    """ContinuousDeploymentConfiguration.

    :param account_configuration:
    :type account_configuration: :class:`ResourceConfiguration
     <azuretfs.models.ResourceConfiguration>`
    :param pipeline_configuration:
    :type pipeline_configuration: :class:`PipelineConfiguration
     <azuretfs.models.PipelineConfiguration>`
    :param project_configuration:
    :type project_configuration: :class:`ResourceConfiguration
     <azuretfs.models.ResourceConfiguration>`
    :param source_configuration:
    :type source_configuration: :class:`SourceConfiguration
     <azuretfs.models.SourceConfiguration>`
    :param target_configuration:
    :type target_configuration: list of :class:`Property
     <azuretfs.models.Property>`
    :param test_configuration:
    :type test_configuration: list of :class:`Property
     <azuretfs.models.Property>`
    """

    _attribute_map = {
        'account_configuration': {'key': 'accountConfiguration', 'type': 'ResourceConfiguration'},
        'pipeline_configuration': {'key': 'pipelineConfiguration', 'type': 'PipelineConfiguration'},
        'project_configuration': {'key': 'projectConfiguration', 'type': 'ResourceConfiguration'},
        'source_configuration': {'key': 'sourceConfiguration', 'type': 'SourceConfiguration'},
        'target_configuration': {'key': 'targetConfiguration', 'type': '[Property]'},
        'test_configuration': {'key': 'testConfiguration', 'type': '[Property]'},
    }

    def __init__(self, account_configuration=None, pipeline_configuration=None, project_configuration=None, source_configuration=None, target_configuration=None, test_configuration=None):
        self.account_configuration = account_configuration
        self.pipeline_configuration = pipeline_configuration
        self.project_configuration = project_configuration
        self.source_configuration = source_configuration
        self.target_configuration = target_configuration
        self.test_configuration = test_configuration
