# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator 1.0.1.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PipelineConfiguration(Model):
    """PipelineConfiguration.

    :param client_type:
    :type client_type: object
    :param prod_environment_name:
    :type prod_environment_name: str
    :param test_environment_name:
    :type test_environment_name: str
    """

    _attribute_map = {
        'client_type': {'key': 'clientType', 'type': 'object'},
        'prod_environment_name': {'key': 'prodEnvironmentName', 'type': 'str'},
        'test_environment_name': {'key': 'testEnvironmentName', 'type': 'str'},
    }

    def __init__(self, client_type=None, prod_environment_name=None, test_environment_name=None):
        self.client_type = client_type
        self.prod_environment_name = prod_environment_name
        self.test_environment_name = test_environment_name
